@@ -159,7 +159,7 @@ class Controller(WSGIController):
             member = self.get_entity_or_404(id)
         self.member = member
 
-    def set_collection(self, q=None, extra_filters=None):
+    def set_collection(self, q=None, extra_filters=None, filter_params=None):
         q = q if q is not None else self.db_session.query(self.entity)
 
         # Apply "global" (i.e., every request) filters
@@ -170,6 +170,8 @@ class Controller(WSGIController):
         # Apply per-request filters
         filters = self._set_filters_from_params(self.base_filter_params)
         filters.update(self._set_filters_from_params(self.filter_params))
+        if filter_params is not None:
+            filters.update(self._set_filters_from_params(filter_params))
 
         distinct = asbool(filters.pop('distinct', False))
         offset = filters.pop('offset', filters.pop('start', None))
@@ -204,11 +206,14 @@ class Controller(WSGIController):
         params = request.params
         for name in filter_params:
             if name in params:
-                # Use param value unless it's blank. XXX: Don't strip?
+                # Get value from request params. If the value is not blank,
+                # that value is used; otherwise, we use the default value.
                 val = params.get(name)
-                if val.strip() == '':
+                if not val:
                     val = filter_params[name]
             else:
+                # Param wasn't passed in request params, so use the default
+                # value.
                 val = filter_params[name]
             if val is not NoDefaultValue:
                 if callable(val):
